#include "Wire.h" // Library for I2C communication
#include "LiquidCrystal_I2C.h" // Library for LCD
#include <ezButton.h>
#include <ezBuzzer.h>
#include "pitches.h"

// Wiring: SDA pin is connected to A4 and SCL pin to A5. Connect to LCD via I2C, default address 0x27 (A0-A2 not jumpered)
LiquidCrystal_I2C lcd = LiquidCrystal_I2C(0x27, 16, 2);
const int BUZZER_PIN = 4;
const int REDLIGHT_PIN = 6;
const int GREENLIGHT_PIN = 7;

ezButton button(2);  // create ezButton object that attach to pin 7;
ezButton rollButton(3);  // create ezButton object that attach to pin 7;
ezBuzzer buzzer(BUZZER_PIN);

// variables
int buttonState = 0;  // variable for reading the pushbutton status
int whichDice = 0; // houdt bij welke dice het is
int dice[] = {4,6,8,10,12,20,100}; //de dice opties
int diceThrow;

// notes in the melody for when you WINNNNNNN:
int melodyWin[] = {NOTE_A5, NOTE_B5, NOTE_C5, NOTE_B5, NOTE_A5};
int noteDurationsWin[] = {4, 8, 4, 4, 2};

// notes in the melody for when you LOSEEEEEE:
int melodyLose[] = {NOTE_G4, NOTE_A4, NOTE_C5, NOTE_A4, NOTE_E5, NOTE_E5, REST, NOTE_D5};
int noteDurationsLose[] = {8, 8, 8, 8, 2, 12, 8, 2};

void setup() {
  lcd.init();   // Initiate the LCD
  lcd.backlight(); //zet de backlight aan
  Serial.begin(9600);
  button.setDebounceTime(50); // set debounce time to 50 milliseconds

  pinMode(REDLIGHT_PIN, OUTPUT);
  pinMode(GREENLIGHT_PIN, OUTPUT);

  Serial.println("Start!"); //check of de code start
}

void loop() {
  button.loop(); // MUST call the loop() function first
  rollButton.loop(); // MUST call the loop() function first
  buzzer.loop(); // MUST call the buzzer.loop() function in loop()

  lcd.setCursor(0, 0); // Set the cursor on the third column and first row.
  lcd.print("Dice is een d");
  lcd.print(dice[whichDice]);

  //if (buttonState == HIGH) {
  if(button.isPressed()){
    diceSelector();
  }
  
  if(rollButton.isPressed()){
    diceRoller();
  }
}

void diceSelector(){
  lcd.clear();
    Serial.println("Je klikt op knopje yay");
    whichDice ++;

    if(whichDice>6){
      whichDice = 0;
    }
}

void diceRoller(){
    lcd.clear();
    diceThrow = random(1, dice[whichDice]+1);

    rolling();

    lcd.clear();
    lcd.setCursor(7, 1);
    lcd.print(diceThrow);

    int whatLight;

    //crit success
    if (diceThrow == dice[whichDice]){  //kijkt of het gerolde nummer gelijk is aan het maximum
      int whatLight = GREENLIGHT_PIN;

        if (buzzer.getState() == BUZZER_IDLE) {
        int length = sizeof(noteDurationsWin) / sizeof(int);
        buzzer.playMelody(melodyWin, noteDurationsWin, length); // playing
      }
      lightsAndDisplay(whatLight);
    }

    //crit fail
    if (diceThrow == 1){    //kijkt of het gerolde nummer 1 is (het laagste nummer)
      int whatLight = REDLIGHT_PIN;

      if (buzzer.getState() == BUZZER_IDLE) {
        int length = sizeof(noteDurationsLose) / sizeof(int);
        buzzer.playMelody(melodyLose, noteDurationsLose, length); // playing
      }
      lightsAndDisplay(whatLight);
    }
}

void rolling(){
  int howManyTimesRolling = random(7,13);
  for (int i = 0; i <= howManyTimesRolling; i++) {
    lcd.setCursor(7, 1);
    lcd.print(random(1, dice[whichDice]+1));
    delay(100);
    lcd.clear();
  }
  delay(150);
}

void lightsAndDisplay(int whatLight){
        digitalWrite(whatLight, HIGH);  // turn the LED on (HIGH is the voltage level)
        lcd.display();
        delay(300);

        digitalWrite(whatLight, LOW);  // turn the LED on (HIGH is the voltage level)
        delay(100);

        digitalWrite(whatLight, HIGH);  // turn the LED on (HIGH is the voltage level)
        lcd.noDisplay();
        delay(150);

        digitalWrite(whatLight, LOW);  // turn the LED on (HIGH is the voltage level)
        delay(200);

        digitalWrite(whatLight, HIGH);  // turn the LED on (HIGH is the voltage level)
        lcd.display();
        delay(100);

        digitalWrite(whatLight, LOW);  // turn the LED on (HIGH is the voltage level)
}